#!/bin/sh

### BEGIN INIT INFO
# Provides:          maxwell-prepare
# Required-Start:    $syslog
# Required-Stop:     $syslog
# Default-Start:     5
# Default-Stop:      0 1 2 3 4 6 7
# Short-Description: Maxwell environment preparation
# Description:
### END INIT INFO

. /etc/init.d/init-functions

ENVFILE=/var/run/environment

# Paths to the watchdog statistic/backup file
WD_STATS_FILE="/var/volatile/wd_stats.json"
BACKUP_FILE="/config/wd_stats.json"

do_start ()
{
    # Truncate environment file
    : > ${ENVFILE}

    # If booting from NFS create nfs_mode lock to disable NetworkManager-based network configuration.
    # TODO Remove when GPMB-554 is done
    NFS_MOUNTED=`mount | grep nfs`
    if [ -n "${NFS_MOUNTED}" ]; then
        touch /var/lock/nfs_mode
    fi

    # Configure keypad for target's Qt-based applications
    KEYBOARD=`ls -la /sys/class/input | grep keypad | grep event | awk '{ print $9}'`
    export QWS_KEYBOARD="LinuxInput:/dev/input/${KEYBOARD}"
    if [ -n ${KEYBOARD} ]; then
        log_info "Keypad detected and set for ${KEYBOARD}"
    else
        log_warning "Keypad has not been detected !"
    fi

    echo "QWS_KEYBOARD=\"${QWS_KEYBOARD}\"" >> ${ENVFILE}

    # Configure hookswitch
    HOOKSWITCH=`ls -la /sys/class/input | grep hookswitch | grep event | awk '{ print $9}'`
    if [ -n ${HOOKSWITCH} ]; then
        log_info "Hookswitch detected and set for ${HOOKSWITCH}"
    else
        log_warning "Hookswitch has not been detected !"
    fi

    echo "HOOKSWITCH=\"${HOOKSWITCH}\"" >> ${ENVFILE}

    sqlite3 /www/pages/webui.db "update webui_users set sessionID=null;"

    # Restore watchdog stats file during reboot
    if [ -f $BACKUP_FILE ]; then
        cp $BACKUP_FILE $WD_STATS_FILE
        rm -f $BACKUP_FILE
    fi

    rm -f /dev/shm/SETTINGS_WORKSPACE
    rm -f /dev/shm/SETTINGS_WORKSPACE_READY
}

do_stop ()
{
    unset QWS_KEYBOARD;
}

case $1 in
    start)
        do_start;
        ;;

    stop)
        do_stop;
        ;;
    *)
        echo "Usage: $0 {start|stop}"
        exit 1
        ;;
esac

