#!/bin/bash
# Copyright 2017 Gigaset Communications GmbH

source maxwell-log-functions.sh

PROPCLI="/usr/sbin/propcli"
TCPDUMP="/usr/sbin/tcpdump"
PACKETS_TILL_AUTOMATIC_STOP=400
FILE_COUNT=1
FILE_PATH="/var/volatile/pcap/sip.pcap"
SIP_PORT_PROPERTY_NAME="SIP.Port"
STATE_PROPERTY_NAME="State.Network.SIP_PCAP"
PIDFILE="/var/run/maxwell-sip-pcap.pid"

case "$1" in
	start)
		SIP_PORT=$($PROPCLI get $SIP_PORT_PROPERTY_NAME)
		if [ $? -ne 0 ]; then
			log_error "Can't get SIP port"
			$($PROPCLI set $STATE_PROPERTY_NAME stopped)
			exit 1
		fi

		OPTS="-n port $SIP_PORT -c $PACKETS_TILL_AUTOMATIC_STOP -W $FILE_COUNT -Uw $FILE_PATH"
		log_info "Starting script"
		start-stop-daemon -S -b -x "$TCPDUMP" -m -p $PIDFILE -- $OPTS
		$($PROPCLI set $STATE_PROPERTY_NAME started)
		;;
	stop)
		log_info "Stopping script"
		start-stop-daemon -K -x "$TCPDUMP" -p $PIDFILE
		$($PROPCLI set $STATE_PROPERTY_NAME stopped)
		rm -f $PIDFILE
		;;
	delete)
		rm -f $FILE_PATH
		$($PROPCLI set $STATE_PROPERTY_NAME deleted)
		;;
	started|stopped|deleted)
		;;
	*)
		log_info "Usage is: $0 {start|stop|delete}" >&2
		exit 1
		;;
esac

exit 0
